@@ -8,6 +8,7 @@ warnings.filterwarnings('ignore', message='RequestsDependencyWarning')
 lazyops_root = os.path.abspath(os.path.dirname(__file__))
 from .lazyclasses import lazyclass
 
+
 from .envs import LazyEnv, get_logger, lazywatcher, lazywatch
 from .models import LazyData, LazyTime, LazyDate, LazyFormatter, LazyTimer, LazyObject
 from .common import lazylibs, lazy_init, run_cmd, clone_repo, File
@@ -15,6 +16,7 @@ from .utils import find_binary_in_path, timed_cache, latest_tf_ckpt, require_mod
 from .utils import build_chunks, retryable, list_to_dict
 from .mp import lazy_parallelize, lazyproc, lazymultiproc, LazyProcs, LazyProc
 from .apis import LazyAPI, LazyAPIConfig
+from .lazyio import LazyHFModel
 
 lazyenv = LazyEnv
 lazyitem = LazyData
@@ -39,6 +41,7 @@ __all__ = [
     'LazyFormatter',
     'LazyTimer',
     'LazyObject',
+    'LazyHFModel',
     'lazylibs',
     'lazy_init',
     'run_cmd',
